# Changelog

## 1.39.0 (2025-03-12)

Full Changelog: [v1.38.0...v1.39.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.38.0...v1.39.0)

### Features

* **api:** api update ([#124](https://github.com/roarkhq/sdk-roark-analytics-python/issues/124)) ([917ee14](https://github.com/roarkhq/sdk-roark-analytics-python/commit/917ee144d1272595c59e43686c1a8a7051263932))

## 1.38.0 (2025-03-11)

Full Changelog: [v1.37.0...v1.38.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.37.0...v1.38.0)

### Features

* **api:** api update ([#122](https://github.com/roarkhq/sdk-roark-analytics-python/issues/122)) ([ef4a697](https://github.com/roarkhq/sdk-roark-analytics-python/commit/ef4a697d85239e8416fff0f97f1c8544a023c692))

## 1.37.0 (2025-03-11)

Full Changelog: [v1.36.0...v1.37.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.36.0...v1.37.0)

### Features

* **api:** api update ([#120](https://github.com/roarkhq/sdk-roark-analytics-python/issues/120)) ([bc21739](https://github.com/roarkhq/sdk-roark-analytics-python/commit/bc2173936a95c6b21726f965a9bcaddcc73b65f2))

## 1.36.0 (2025-03-10)

Full Changelog: [v1.35.0...v1.36.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.35.0...v1.36.0)

### Features

* **api:** api update ([#115](https://github.com/roarkhq/sdk-roark-analytics-python/issues/115)) ([e4858f5](https://github.com/roarkhq/sdk-roark-analytics-python/commit/e4858f531e2bad3b45356e02ff2fadc7e2dab7f2))

## 1.35.0 (2025-03-10)

Full Changelog: [v1.34.0...v1.35.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.34.0...v1.35.0)

### Features

* **api:** api update ([#112](https://github.com/roarkhq/sdk-roark-analytics-python/issues/112)) ([3ccb899](https://github.com/roarkhq/sdk-roark-analytics-python/commit/3ccb8994a158db74bacd774baededc34c7c75b43))

## 1.34.0 (2025-03-10)

Full Changelog: [v1.33.0...v1.34.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.33.0...v1.34.0)

### Features

* **api:** api update ([#109](https://github.com/roarkhq/sdk-roark-analytics-python/issues/109)) ([f4647cb](https://github.com/roarkhq/sdk-roark-analytics-python/commit/f4647cb8782993ed04805bb89a8845fa20548b92))

## 1.33.0 (2025-03-10)

Full Changelog: [v1.32.0...v1.33.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.32.0...v1.33.0)

### Features

* **api:** api update ([#106](https://github.com/roarkhq/sdk-roark-analytics-python/issues/106)) ([395ff64](https://github.com/roarkhq/sdk-roark-analytics-python/commit/395ff6448c0d314d029664ec8b5e8f9d1a999fa7))

## 1.32.0 (2025-03-09)

Full Changelog: [v1.31.0...v1.32.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.31.0...v1.32.0)

### Features

* **api:** api update ([#103](https://github.com/roarkhq/sdk-roark-analytics-python/issues/103)) ([f550819](https://github.com/roarkhq/sdk-roark-analytics-python/commit/f550819e1c1528813fa1e0eb19ec275b1dfdcc9d))

## 1.31.0 (2025-03-09)

Full Changelog: [v1.30.0...v1.31.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.30.0...v1.31.0)

### Features

* **api:** api update ([#100](https://github.com/roarkhq/sdk-roark-analytics-python/issues/100)) ([97b8cd0](https://github.com/roarkhq/sdk-roark-analytics-python/commit/97b8cd089023c402272830a91ccc35d170c43cf3))

## 1.30.0 (2025-03-09)

Full Changelog: [v1.29.0...v1.30.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.29.0...v1.30.0)

### Features

* **api:** api update ([#97](https://github.com/roarkhq/sdk-roark-analytics-python/issues/97)) ([125818a](https://github.com/roarkhq/sdk-roark-analytics-python/commit/125818af562cd5ae8dea611d817c683ca2b8de11))

## 1.29.0 (2025-03-09)

Full Changelog: [v1.28.0...v1.29.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.28.0...v1.29.0)

### Features

* **api:** api update ([#94](https://github.com/roarkhq/sdk-roark-analytics-python/issues/94)) ([f4c4248](https://github.com/roarkhq/sdk-roark-analytics-python/commit/f4c42480f3c0a94b84d3bd6220cc3ec5c7d39460))

## 1.28.0 (2025-03-09)

Full Changelog: [v1.27.0...v1.28.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.27.0...v1.28.0)

### Features

* **api:** api update ([#91](https://github.com/roarkhq/sdk-roark-analytics-python/issues/91)) ([ed54014](https://github.com/roarkhq/sdk-roark-analytics-python/commit/ed5401457440edba4d00330825416399a93d996a))

## 1.27.0 (2025-03-08)

Full Changelog: [v1.26.0...v1.27.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.26.0...v1.27.0)

### Features

* **api:** api update ([#88](https://github.com/roarkhq/sdk-roark-analytics-python/issues/88)) ([51018fb](https://github.com/roarkhq/sdk-roark-analytics-python/commit/51018fb2e21d414ff4c3546e15bfbd2ea188d012))

## 1.26.0 (2025-03-08)

Full Changelog: [v1.25.0...v1.26.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.25.0...v1.26.0)

### Features

* **api:** api update ([#85](https://github.com/roarkhq/sdk-roark-analytics-python/issues/85)) ([c2e4a4f](https://github.com/roarkhq/sdk-roark-analytics-python/commit/c2e4a4f8767b0fd7466abe7da1f8b26fbba86375))

## 1.25.0 (2025-03-07)

Full Changelog: [v1.24.0...v1.25.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.24.0...v1.25.0)

### Features

* **api:** api update ([#82](https://github.com/roarkhq/sdk-roark-analytics-python/issues/82)) ([0c3a405](https://github.com/roarkhq/sdk-roark-analytics-python/commit/0c3a4050fdff03a3e9ae91634196febaa799e594))

## 1.24.0 (2025-03-07)

Full Changelog: [v1.23.0...v1.24.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.23.0...v1.24.0)

### Features

* **api:** api update ([#79](https://github.com/roarkhq/sdk-roark-analytics-python/issues/79)) ([8e9f90c](https://github.com/roarkhq/sdk-roark-analytics-python/commit/8e9f90c697beee94d80a4d68ae42e119da2512bb))

## 1.23.0 (2025-03-07)

Full Changelog: [v1.22.0...v1.23.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.22.0...v1.23.0)

### Features

* **api:** api update ([#76](https://github.com/roarkhq/sdk-roark-analytics-python/issues/76)) ([3466233](https://github.com/roarkhq/sdk-roark-analytics-python/commit/346623375165a2bf8674acdec71ad68654174a1d))

## 1.22.0 (2025-03-07)

Full Changelog: [v1.21.0...v1.22.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.21.0...v1.22.0)

### Features

* **api:** api update ([#73](https://github.com/roarkhq/sdk-roark-analytics-python/issues/73)) ([558d185](https://github.com/roarkhq/sdk-roark-analytics-python/commit/558d18522098a1d4c10127deb5d466c4fc6d499c))

## 1.21.0 (2025-03-07)

Full Changelog: [v1.20.0...v1.21.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.20.0...v1.21.0)

### Features

* **api:** api update ([#70](https://github.com/roarkhq/sdk-roark-analytics-python/issues/70)) ([1371202](https://github.com/roarkhq/sdk-roark-analytics-python/commit/1371202b9bef6b06bc7f06721ba898d3937c7e71))

## 1.20.0 (2025-03-06)

Full Changelog: [v1.19.0...v1.20.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.19.0...v1.20.0)

### Features

* **api:** api update ([#67](https://github.com/roarkhq/sdk-roark-analytics-python/issues/67)) ([5bbfc48](https://github.com/roarkhq/sdk-roark-analytics-python/commit/5bbfc4814ffbf6c662ddece803b62a066c3c4c7a))

## 1.19.0 (2025-03-06)

Full Changelog: [v1.18.0...v1.19.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.18.0...v1.19.0)

### Features

* **api:** api update ([#64](https://github.com/roarkhq/sdk-roark-analytics-python/issues/64)) ([189b166](https://github.com/roarkhq/sdk-roark-analytics-python/commit/189b1668fd6fe7f368050b03e0ce7cab244ae77a))

## 1.18.0 (2025-03-06)

Full Changelog: [v1.17.0...v1.18.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.17.0...v1.18.0)

### Features

* **api:** api update ([#61](https://github.com/roarkhq/sdk-roark-analytics-python/issues/61)) ([ca09e8c](https://github.com/roarkhq/sdk-roark-analytics-python/commit/ca09e8cd5b92b0220c818df9060f9a3b58a1f3fe))

## 1.17.0 (2025-03-05)

Full Changelog: [v1.16.0...v1.17.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.16.0...v1.17.0)

### Features

* **api:** api update ([#58](https://github.com/roarkhq/sdk-roark-analytics-python/issues/58)) ([066a58e](https://github.com/roarkhq/sdk-roark-analytics-python/commit/066a58edb42fc8fb95c734c98f2b0bcbae5df534))

## 1.16.0 (2025-03-05)

Full Changelog: [v1.15.0...v1.16.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.15.0...v1.16.0)

### Features

* **api:** api update ([#55](https://github.com/roarkhq/sdk-roark-analytics-python/issues/55)) ([7ced7a0](https://github.com/roarkhq/sdk-roark-analytics-python/commit/7ced7a0e1a5ccc12ac02b92dfdb39d8da54670f4))

## 1.15.0 (2025-03-04)

Full Changelog: [v1.14.0...v1.15.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.14.0...v1.15.0)

### Features

* **api:** api update ([#53](https://github.com/roarkhq/sdk-roark-analytics-python/issues/53)) ([2c58660](https://github.com/roarkhq/sdk-roark-analytics-python/commit/2c586604a7de5f85976b2f893826d9ad94f68273))


### Chores

* **internal:** remove unused http client options forwarding ([#51](https://github.com/roarkhq/sdk-roark-analytics-python/issues/51)) ([1e7213d](https://github.com/roarkhq/sdk-roark-analytics-python/commit/1e7213ddfb3bc2c3b07d23f8fd8ef1d22b784bb9))

## 1.14.0 (2025-03-03)

Full Changelog: [v1.13.0...v1.14.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.13.0...v1.14.0)

### Features

* **api:** api update ([#48](https://github.com/roarkhq/sdk-roark-analytics-python/issues/48)) ([a74f998](https://github.com/roarkhq/sdk-roark-analytics-python/commit/a74f9985b2427404226d31a5910296c1a0f4b639))

## 1.13.0 (2025-03-03)

Full Changelog: [v1.12.0...v1.13.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.12.0...v1.13.0)

### Features

* **api:** api update ([#45](https://github.com/roarkhq/sdk-roark-analytics-python/issues/45)) ([4bf8b68](https://github.com/roarkhq/sdk-roark-analytics-python/commit/4bf8b68a21c3e7fea99a86b0a92e1d3f9de55391))

## 1.12.0 (2025-03-03)

Full Changelog: [v1.11.0...v1.12.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.11.0...v1.12.0)

### Features

* **api:** api update ([#42](https://github.com/roarkhq/sdk-roark-analytics-python/issues/42)) ([9b6bd6d](https://github.com/roarkhq/sdk-roark-analytics-python/commit/9b6bd6d9fe082a2da236b47821266c901ad04deb))

## 1.11.0 (2025-03-03)

Full Changelog: [v1.10.0...v1.11.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.10.0...v1.11.0)

### Features

* **api:** api update ([#40](https://github.com/roarkhq/sdk-roark-analytics-python/issues/40)) ([224643d](https://github.com/roarkhq/sdk-roark-analytics-python/commit/224643d317c338420a4dd9b1f5d62e890ae71882))

## 1.10.0 (2025-03-03)

Full Changelog: [v1.9.0...v1.10.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.9.0...v1.10.0)

### Features

* **api:** api update ([#37](https://github.com/roarkhq/sdk-roark-analytics-python/issues/37)) ([0dc33e1](https://github.com/roarkhq/sdk-roark-analytics-python/commit/0dc33e1dbe26e1e0db8eb2385633ca23c970b9d7))

## 1.9.0 (2025-03-03)

Full Changelog: [v1.8.0...v1.9.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.8.0...v1.9.0)

### Features

* **api:** api update ([#34](https://github.com/roarkhq/sdk-roark-analytics-python/issues/34)) ([b8c1aae](https://github.com/roarkhq/sdk-roark-analytics-python/commit/b8c1aae395fac95af739e3a142a20946ecabf20d))

## 1.8.0 (2025-03-02)

Full Changelog: [v1.7.0...v1.8.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.7.0...v1.8.0)

### Features

* **api:** api update ([#31](https://github.com/roarkhq/sdk-roark-analytics-python/issues/31)) ([f882512](https://github.com/roarkhq/sdk-roark-analytics-python/commit/f8825129f8faab6ff1ddf4e3936b7825b1bde8fa))

## 1.7.0 (2025-03-02)

Full Changelog: [v1.6.0...v1.7.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.6.0...v1.7.0)

### Features

* **api:** api update ([#28](https://github.com/roarkhq/sdk-roark-analytics-python/issues/28)) ([1b360c9](https://github.com/roarkhq/sdk-roark-analytics-python/commit/1b360c9324a549836a61c5dd3c72835eed455cd4))

## 1.6.0 (2025-03-02)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.5.0...v1.6.0)

### Features

* **api:** api update ([#25](https://github.com/roarkhq/sdk-roark-analytics-python/issues/25)) ([587972c](https://github.com/roarkhq/sdk-roark-analytics-python/commit/587972cc0d14fd7a3fe2c4af69624cf08f26ac85))

## 1.5.0 (2025-03-02)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.4.0...v1.5.0)

### Features

* **api:** api update ([#22](https://github.com/roarkhq/sdk-roark-analytics-python/issues/22)) ([82b4e82](https://github.com/roarkhq/sdk-roark-analytics-python/commit/82b4e82c8f7bdc42f8507f9657d6b5ec6fac8e0c))

## 1.4.0 (2025-03-02)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.3.0...v1.4.0)

### Features

* **api:** api update ([#19](https://github.com/roarkhq/sdk-roark-analytics-python/issues/19)) ([d4f65b0](https://github.com/roarkhq/sdk-roark-analytics-python/commit/d4f65b0a1aac1b894905f5cd6081c853aa4df0cd))

## 1.3.0 (2025-03-02)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** api update ([#16](https://github.com/roarkhq/sdk-roark-analytics-python/issues/16)) ([2daf82a](https://github.com/roarkhq/sdk-roark-analytics-python/commit/2daf82abd3f3323c8dcfcc71653c9858637b6b45))

## 1.2.0 (2025-03-02)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** api update ([#13](https://github.com/roarkhq/sdk-roark-analytics-python/issues/13)) ([cd54ee6](https://github.com/roarkhq/sdk-roark-analytics-python/commit/cd54ee6eaaa998a59c9ecade8985ffab77295051))

## 1.1.0 (2025-03-02)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** api update ([#11](https://github.com/roarkhq/sdk-roark-analytics-python/issues/11)) ([498ac13](https://github.com/roarkhq/sdk-roark-analytics-python/commit/498ac13ef7586ae837c6b6bd8cfc23f56021d2a7))


### Chores

* remove custom code ([a91dd14](https://github.com/roarkhq/sdk-roark-analytics-python/commit/a91dd149213830c1171f6589d8bd60942e2173ca))

## 1.0.0 (2025-03-02)

Full Changelog: [v0.0.1-alpha.1...v1.0.0](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v0.0.1-alpha.1...v1.0.0)

### Chores

* update SDK settings ([#5](https://github.com/roarkhq/sdk-roark-analytics-python/issues/5)) ([2154668](https://github.com/roarkhq/sdk-roark-analytics-python/commit/21546680317c33d97db9a01080735c5c36f2de72))

## 0.0.1-alpha.1 (2025-03-02)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/roarkhq/sdk-roark-analytics-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* configure new SDK language ([3a0391f](https://github.com/roarkhq/sdk-roark-analytics-python/commit/3a0391fe3b558f430b96db64972d1e76d4a7fdee))
* go live ([#1](https://github.com/roarkhq/sdk-roark-analytics-python/issues/1)) ([99e8d20](https://github.com/roarkhq/sdk-roark-analytics-python/commit/99e8d20112aac88bec32befa86cf4853d5f54557))
